Yuio By Example
===============

A simple step-by-step guide that will walk you through Yuio's essentials.

.. tip::

   All GIFs in this tutorial are generated automatically on documentation build.
   If you see anything strange, `open an issue`__!

   __ github.com/taminomara/yuio/issues

.. toctree::
   :maxdepth: 2

   1_hello_world
   2_interactive_things
   3_advanced_apps
   4_configs
